@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Natural Language Toolkit: Interface to the Stanford Part-of-speech and Named-Entity Taggers
 #
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Nitin Madnani <nmadnani@ets.org>
 #         Rami Al-Rfou' <ralrfou@cs.stonybrook.edu>
 # URL: <http://nltk.org/>
@@ -47,6 +47,11 @@ class StanfordTagger(TaggerI):
 
     def __init__(self, model_filename, path_to_jar=None, encoding='utf8',
                  verbose=False, java_options='-mx1000m'):
+        # Raise deprecation warning.
+        warnings.warn(str("\nThe StanfordTokenizer will "
+                          "be deprecated in version 3.2.6.\n"
+                          "Please use \033[91mnltk.parse.corenlp.CoreNLPParser\033[0m instead."),
+                      DeprecationWarning, stacklevel=2)
 
         if not self._JAR:
             warnings.warn('The StanfordTagger class is not meant to be '
