@@ -2,7 +2,7 @@
 #
 # Natural Language Toolkit: Twitter Tokenizer
 #
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2018 NLTK Project
 # Author: Christopher Potts <cgpotts@stanford.edu>
 #         Ewan Klein <ewan@inf.ed.ac.uk> (modifications)
 #         Pierpaolo Pantone <> (modifications)
@@ -38,8 +38,9 @@ domains and tasks. The basic logic is this:
 
 from __future__ import unicode_literals
 import re
-from nltk.compat import htmlentitydefs, int2byte, unichr
 
+from six import int2byte, unichr
+from six.moves import html_entities
 
 ######################################################################
 # The following strings are components in the regular expression
@@ -126,15 +127,15 @@ REGEXPS = (
     (?:
       (?:            # (international)
         \+?[01]
-        [\-\s.]*
+        [ *\-.\)]*
       )?
       (?:            # (area code)
         [\(]?
         \d{3}
-        [\-\s.\)]*
+        [ *\-.\)]*
       )?
       \d{3}          # exchange
-      [\-\s.]*
+      [ *\-.\)]*
       \d{4}          # base
     )"""
     ,
@@ -246,7 +247,7 @@ def _replace_html_entities(text, keep=(), remove_illegal=True, encoding='utf-8')
             if entity_body in keep:
                 return match.group(0)
             else:
-                number = htmlentitydefs.name2codepoint.get(entity_body)
+                number = html_entities.name2codepoint.get(entity_body)
         if number is not None:
             try:
                 return unichr(number)
@@ -340,4 +341,3 @@ def casual_tokenize(text, preserve_case=True, reduce_len=False, strip_handles=Fa
                           strip_handles=strip_handles).tokenize(text)
 
 ###############################################################################
-
